@@ -23,7 +23,7 @@ class NLProcessor:
     determining the similarity of strings, and others.
     """
 
-    def __init__(self, init_pullenti: bool):
+    def __init__(self, init_pullenti=True):
         """
         :param init_pullenti: is it necessary to initialize the pullenti SDK.
         """
